==> form-dinamico-react-render-0.1.2.tgz: package/es/components/FileGrid.js <==
import React from 'react';

import { withStyles } from 'material-ui/styles/index';

import { GridList, GridListTile, GridListTileBar } from 'material-ui/GridList';
import IconButton from 'material-ui/IconButton';
import DeleteIcon from '@material-ui/icons/Delete';

var fileGridStyles = function fileGridStyles(theme) {
    return {
        container: {
            display: 'flex',
            flexWrap: 'wrap',
            justifyContent: 'space-around',
            overflow: 'hidden',
            background: theme.palette.background.paper
        },
        gridList: {}
    };
};

var FileGrid = function FileGrid(_ref) {
    var classes = _ref.classes,
        files = _ref.files,
        onDeleteClick = _ref.onDeleteClick;
    return React.createElement(
        'div',
        { className: classes.container },
        React.createElement(
            GridList,
            { className: classes.gridList },
            files.map(function (file, index) {
                return React.createElement(
                    GridListTile,
                    { key: index },
                    React.createElement('img', {
                        src: file.link,
                        alt: file.name
                    }),
                    React.createElement(GridListTileBar, {
                        title: file.name,
                        subtitle: React.createElement(
                            'span',
                            null,
                            file.length + ' bytes'
                        ),
                        actionIcon: React.createElement(
                            IconButton,
                            { onClick: function onClick() {
                                    return onDeleteClick(file, index);
                                } },
                            React.createElement(DeleteIcon, { color: 'rgba(255, 255, 255, 0.54)' })
                        )
                    })
                );
            })
        )
    );
};

export default withStyles(fileGridStyles)(FileGrid);

==> form-dinamico-react-render-0.1.3.tgz: package/es/components/FileGrid.js <==
import React from 'react';

import { withStyles } from 'material-ui/styles/index';

import GridList, { GridListTile, GridListTileBar } from 'material-ui/GridList';

import IconButton from 'material-ui/IconButton';
import DeleteIcon from '@material-ui/icons/Delete';

var fileGridStyles = function fileGridStyles(theme) {
    return {
        container: {
            display: 'flex',
            flexWrap: 'wrap',
            justifyContent: 'space-around',
            overflow: 'hidden',
            background: theme.palette.background.paper
        },
        gridList: {}
    };
};

var FileGrid = function FileGrid(_ref) {
    var classes = _ref.classes,
        files = _ref.files,
        onDeleteClick = _ref.onDeleteClick;
    return React.createElement(
        'div',
        { className: classes.container },
        React.createElement(
            GridList,
            { className: classes.gridList },
            files.map(function (file, index) {
                return React.createElement(
                    GridListTile,
                    { key: index },
                    '' + file.type.startsWith('image'),
                    React.createElement('img', {
                        src: file.preview ? file.preview : file.link,
                        alt: file.name
                    }),
                    React.createElement(GridListTileBar, {
                        title: file.name,
                        subtitle: React.createElement(
                            'span',
                            null,
                            file.length + ' bytes'
                        ),
                        actionIcon: React.createElement(
                            IconButton,
                            { onClick: function onClick() {
                                    return onDeleteClick(file, index);
                                } },
                            React.createElement(DeleteIcon, { color: 'disabled' })
                        )
                    })
                );
            })
        )
    );
};

export default withStyles(fileGridStyles)(FileGrid);
